@@ -1,6 +1,6 @@
 /*
 PStreams - POSIX Process I/O for C++
-Copyright (C) 2002-2014 Jonathan Wakely
+Copyright (C) 2002-2016 Jonathan Wakely
 
 This file is part of PStreams.
 
@@ -61,8 +61,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # endif
 #endif
 
-using namespace std;
 using namespace redi;
+using std::clog;
+using std::cout;
+using std::wcout;
+using std::endl;
 
 #if 0
 // specialise basic_pstreambuf<char>::sync() to add a delay, allowing
@@ -96,15 +99,15 @@ namespace  // anon
     // helper functions for printing test results
 
     void
-    test_type(istream const&, char& c, int& i)
+    test_type(std::istream const&, char& c, int& i)
     { static int count=0; c='r'; i=++count; }
 
     void
-    test_type(ostream const&, char& c, int& i)
+    test_type(std::ostream const&, char& c, int& i)
     { static int count=0; c='w'; i=++count; }
 
     void
-    test_type(iostream const&, char& c, int& i)
+    test_type(std::iostream const&, char& c, int& i)
     { static int count=0; c='b'; i=++count; }
 
     void
@@ -112,13 +115,13 @@ namespace  // anon
     { static int count=0; c='x'; i=++count; }
 
     template <typename T>
-    string
+    std::string
     test_id(T const& s)
     {
         char label = '?';
         int count = 0;
         test_type(s, label, count);
-        ostringstream buf;
+        std::ostringstream buf;
         buf << label << count;
         return buf.str();
     }
@@ -127,7 +130,7 @@ namespace  // anon
     void
     print_result(T const& s, bool result)
     {
-        clog << "Test " << setw(4) << test_id(s) << ": "
+        clog << "Test " << std::setw(4) << test_id(s) << ": "
             << (result ? "Pass" : "Fail!")
             << endl;
         exit_status += !result;
@@ -159,12 +162,12 @@ extern "C" void my_sig_handler(int) { ++sig_counter; }
 
 int main()
 {
-    ios_base::sync_with_stdio();
+    std::ios_base::sync_with_stdio();
 
     const pstreams::pmode all3streams =
         pstreams::pstdin|pstreams::pstdout|pstreams::pstderr;
 
-    string str;
+    std::string str;
 
     clog << "# Testing basic I/O\n";
 
@@ -219,7 +222,7 @@ int main()
 
         opstream sed("sed 's/^/STDIN: /'");
         str = "Monkey Magic\n";
-        for (string::const_iterator i = str.begin(); i!=str.end(); ++i)
+        for (std::string::const_iterator i = str.begin(); i!=str.end(); ++i)
             sed.put(*i);
         check_pass(sed);
     }
@@ -246,7 +249,7 @@ int main()
         char c;
         while (host.get(c))  // extracts up to EOF (including newline)
             str += c;
-        cout << "STDOUT:  " << str << flush;
+        cout << "STDOUT:  " << str << std::flush;
         print_result(host, host.eof());
     }
 
@@ -258,7 +261,7 @@ int main()
         argv.push_back("date");
         ipstream is1(argv[0], argv);
         ipstream is2(argv);
-        string s1, s2;
+        std::string s1, s2;
         getline(is1, s1);
         getline(is2, s2);
         cout << "STDOUT:  " << s1 << endl;
@@ -275,7 +278,7 @@ int main()
         argv.push_back("/nosuchdir/nosuchfile");
         ipstream is1(argv[0], argv, pstreams::pstderr);
         ipstream is2(argv, pstreams::pstderr);
-        string s1, s2;
+        std::string s1, s2;
         getline(is1, s1);
         getline(is2, s2);
         cout << "STDERR:  " << s1 << endl;
@@ -295,7 +298,7 @@ int main()
         // open after construction, then read
         ipstream is;
         is.open("hostname");
-        string s;
+        std::string s;
         is >> s;
         cout << "STDOUT: " << s << endl;
         check_pass(is);
@@ -320,7 +323,7 @@ int main()
     {
         // test reading from bidirectional pstream
 
-        const string cmd = "grep '^127' /etc/hosts /no/such/file /dev/stdin";
+        const std::string cmd = "grep '^127' /etc/hosts /no/such/file /dev/stdin";
 
         pstream ps(cmd, all3streams);
 
@@ -330,7 +333,7 @@ int main()
 
         ps << "127721\n" << peof;
 
-        string buf;
+        std::string buf;
         while (getline(ps.out(), buf))
             cout << "STDOUT: " << buf << endl;
         check_fail(ps);
@@ -345,7 +348,7 @@ int main()
         // test input on bidirectional pstream
         // and test child moves onto next file after peof on stdin
 
-        const string cmd = "grep fnord /etc/hosts /dev/stdin";
+        const std::string cmd = "grep fnord /etc/hosts /dev/stdin";
 
         pstream ps(cmd, all3streams);
 
@@ -355,7 +358,7 @@ int main()
         ps << "12345\nfnord\n0000" << peof;
         // manip calls ps.rdbuf()->peof();
 
-        string buf;
+        std::string buf;
         getline(ps.out(), buf);
 
         do
@@ -369,7 +372,7 @@ int main()
 
     {
         // test signals
-        const string cmd = "grep 127 -- -";
+        const std::string cmd = "grep 127 -- -";
         pstream ps(cmd, all3streams);
 
         ps << "fnord";  // write some output to buffer
@@ -394,7 +397,7 @@ int main()
 
     {
         // test killing and checking for exit
-        const string cmd = "grep '^127' -- -";
+        const std::string cmd = "grep '^127' -- -";
         pstream ps(cmd, all3streams);
 
         print_result(ps, ps.is_open());
@@ -407,7 +410,7 @@ int main()
         print_result(ps, ps.rdbuf()->exited());
         print_result(ps, !ps.is_open());
 
-        string buf;
+        std::string buf;
         while (getline(ps.out(), buf))
             cout << "STDOUT: " << buf << endl;
         check_fail(ps);
@@ -421,7 +424,7 @@ int main()
     clog << "# Testing pstreambuf::exited()" << endl;
     {
         // test streambuf::exited() works sanely
-        const string cmd = "cat";
+        const std::string cmd = "cat";
         opstream ps;
         pstreambuf* pbuf = ps.rdbuf();
 
@@ -446,8 +449,8 @@ int main()
 
     clog << "# Testing behaviour with bad commands" << endl;
 
-    //string badcmd = "hgfhdgf";
-    const string badcmd = "hgfhdgf 2>/dev/null";
+    //std::string badcmd = "hgfhdgf";
+    const std::string badcmd = "hgfhdgf 2>/dev/null";
 
     {
         // check is_open() works 
@@ -520,26 +523,26 @@ int main()
     clog << "# Testing other member functions\n";
 
     {
-        const string cmd("grep re");
+        const std::string cmd("grep re");
         opstream s(cmd);
         print_result(s, cmd == s.command());
     }
 
     {
-        const string cmd("grep re");
+        const std::string cmd("grep re");
         opstream s;
         s.open(cmd);
         print_result(s, cmd == s.command());
     }
 
     {
-        const string cmd("/bin/ls");
+        const std::string cmd("/bin/ls");
         ipstream s(cmd);
         print_result(s, cmd == s.command());
     }
 
     {
-        const string cmd("/bin/ls");
+        const std::string cmd("/bin/ls");
         ipstream s;
         s.open(cmd);
         print_result(s, cmd == s.command());
@@ -550,7 +553,7 @@ int main()
         // testing streambuf::in_avail()
         ipstream in("{ printf 'this is ' ; sleep 2 ; printf 'hardcore' ; }");
         sleep(1);
-        streamsize avail = in.rdbuf()->in_avail();
+        std::streamsize avail = in.rdbuf()->in_avail();
         print_result(in, avail > 0);
         print_result(in, size_t(avail) == strlen("this is "));
 
@@ -568,7 +571,7 @@ int main()
                 buf.resize(avail);
                 in.readsome(&buf.front(), avail);
                 cout << "STDOUT: " << avail << " characters: "
-                    << string(buf.begin(), buf.end()) << endl;
+                    << std::string(buf.begin(), buf.end()) << endl;
             }
             else
                 ++tries;
@@ -600,7 +603,7 @@ int main()
     {
         pstream p("tr '[:lower:]' '[:upper:]'");
         p << "newline\neof" << peof;
-        string s;
+        std::string s;
         check_pass(std::getline(p.out(),s));
         print_result(p, s.size()>0);
         cout << "STDOUT: " << s << endl;
@@ -615,7 +618,7 @@ int main()
     {
         rpstream rs("tr '[:lower:]' '[:upper:]'");
         rs << "foo\n" << peof;
-        string s;
+        std::string s;
         check_pass(std::getline(rs.out(),s));
         print_result(rs, s.size()>0);
         cout << "STDOUT: " << s << endl;
@@ -637,7 +640,7 @@ int main()
     clog << "# Testing read position tracked correctly\n";
     {
         ipstream in("echo 'abc' >&2 && echo '123'", all3streams);
-        string s;
+        std::string s;
         s += in.out().get();
         s += in.err().get();
         s += in.out().get();
@@ -645,7 +648,7 @@ int main()
         s += in.out().get();
         s += in.err().get();
 
-        const string s_expected = "1a2b3c";
+        const std::string s_expected = "1a2b3c";
         cout << s << " == " << s_expected << endl;
         print_result(in, s == s_expected);
 
@@ -661,7 +664,7 @@ int main()
     clog << "# Testing initial pmode set correctly\n";
     {
         char c;
-        string s;
+        std::string s;
         ipstream in("echo 'abc' >&2", pstreambuf::pstderr);
         print_result(in, getline(in, s));
         print_result(in, s == "abc");
@@ -702,7 +705,7 @@ int main()
     }
 
     {
-        string cmd = "ls /etc/hosts /no/such/file";
+        std::string cmd = "ls /etc/hosts /no/such/file";
         ipstream is(cmd, pstreambuf::pstdout|pstreambuf::pstderr);
         FILE *in, *out, *err;
         size_t res = is.fopen(in, out, err);
@@ -723,7 +726,7 @@ int main()
     }
 
     {
-        string cmd = "grep 127 -- - /etc/hosts /no/such/file";
+        std::string cmd = "grep 127 -- - /etc/hosts /no/such/file";
         pstream ps(cmd, all3streams);
         FILE *in, *out, *err;
         size_t res = ps.fopen(in, out, err);
@@ -898,7 +901,7 @@ int main()
     {
         ipstream dummy("true");
         basic_ipstream<wchar_t> in("cat ./pstreams.wout");
-        wstring s;
+        std::wstring s;
         in >> s;
         wcout << s;
         print_result(dummy, in);
@@ -920,4 +923,3 @@ int main()
 
     return exit_status;
 }
-
